use strict;
use warnings;

package Test::Deep::Obj;

use Test::Deep::Cmp;
use Scalar::Util;

sub import {
	my $sub = sub {
		return Test::Deep::Obj->new(@_);
	};
	no strict 'refs';
	*{caller . '::obj_isa'} = $sub;
}

sub init
{
	my $self = shift;

	my $val = shift;
	$self->{val} = $val;
}

sub descend
{
	my $self = shift;
	my $got = shift;

	return Scalar::Util::blessed($got)
	  && $got->isa($self->{val});
}

sub diag_message
{
	my $self = shift;

	my $where = shift;

	return "Checking class of $where with isa()";
}

sub renderExp
{
	my $self = shift;

	return "blessed into '$self->{val}' or subclass of '$self->{val}'";
}

1;

=head1 NAME

Test::Deep::Obj - obj_isa() separated from Test-Deep-0.111

=head1 SYNOPSYS

    use Test::Deep;
    use Test::Deep::Obj;

    cmp_deeply($object, obj_isa(...));

=head1 DESCRIPTION

Test-Deep prior 0.111 did not provide B<obj_isa()>. Using B<Test::Deep::Obj>
imports B<obj_isa()> into a caller's name space.

This implementation is copied from Test-Deep-0.111.

=head1 COPYRIGHT

Copyright 2003, 2004 by Fergal Daly E<lt>fergal@esatclear.ieE<gt>.

This program is free software; you can redistribute it and/or
modify it under the same terms as Perl itself.

=cut
